@@ -1,6 +1,7 @@
 """Functions for interacting with SBML models"""
 from warnings import warn
 import logging
+from pandas.io.common import get_handle, is_url, is_file_like
 import re
 from typing import Dict, Any, List, Union, Tuple
 import libsbml
@@ -416,19 +417,10 @@ def get_sbml_model(
         File or URL or file handle to read the model from
     :return: The SBML document, model and reader
     """
-
-    from pandas.io.common import get_filepath_or_buffer, is_url, is_file_like
-
     if is_file_like(filepath_or_buffer) or is_url(filepath_or_buffer):
-        buffer = get_filepath_or_buffer(filepath_or_buffer, mode='r')[0]
-        if is_url(filepath_or_buffer):
-            buffer = ''.join(line.decode('utf-8') for line in buffer)
-        else:
-            buffer = ''.join(line for line in buffer)
-
+        handle = get_handle(filepath_or_buffer, mode='r').handle
         # URL or already opened file, we will load the model from a string
-
-        return load_sbml_from_string(buffer)
+        return load_sbml_from_string(''.join(handle))
 
     return load_sbml_from_file(filepath_or_buffer)
 
